@@ -8,9 +8,10 @@ use strict;
 use vars qw($VERSION @Plugins);
 use Carp;
 
-$VERSION = "2.11";
+$VERSION = "2.13";
 
 @Plugins = qw(
+	Authen::SASL::XS
 	Authen::SASL::Cyrus
 	Authen::SASL::Perl
 );
@@ -70,24 +71,32 @@ sub callback {
 sub client_new { # $self, $service, $host, $secflags
   my $self = shift;
 
+  my $err;
   foreach my $pkg (@Plugins) {
     if (eval "require $pkg" and $pkg->can("client_new")) {
-      return ($self->{conn} = $pkg->client_new($self, @_));
+      if ($self->{conn} = eval { $pkg->client_new($self, @_) }) {
+        return $self->{conn};
+      }
+      $err = $@;
     }
   }
 
-  croak "Cannot find a SASL Connection library";
+  croak $err || "Cannot find a SASL Connection library";
 }
 
 sub server_new { # $self, $service, $host, $secflags
   my $self = shift;
 
+  my $err;
   foreach my $pkg (@Plugins) {
     if (eval "require $pkg" and $pkg->can("server_new")) {
-      return ($self->{conn} = $pkg->server_new($self, @_));
+      if ($self->{conn} = eval { $pkg->server_new($self, @_) } ) {
+        return $self->{conn};
+      }
+      $err = $@;
     }
   }
-  croak "Cannot find a SASL Connection library for server-side authentication";
+  croak $err || "Cannot find a SASL Connection library for server-side authentication";
 }
 
 sub error {
